defaultvalues = {g -> 9.81, tx -> 0.12, tr -> 0.14, den0 -> 4000., COMx -> 0, 
     COMy -> 0, COMz -> 0, m0 -> 3.141592653589793*den0*tr^2*tx, 
     I0x -> (m0*tr^2)/2, I0y -> m0*(tr^2/4 + tx^2/12), 
     I0z -> m0*(tr^2/4 + tx^2/12), l0 -> 0.6, nw0 -> 2, 
     r0 -> 0.00017999999999999998, Y0 -> Ysteel, dpitch -> 0.001, 
     dyaw1 -> dyaw2, dyaw2 -> 2*tr, 
     tl0 -> Sqrt[-(dyaw1/2 - dyaw2/2)^2 + sl0^2], ltotal -> tl0, 
     dpend -> tl0, ul0 -> 
      -((g*m0)/(kw0*nw0*Sqrt[1 - (dyaw1/2 - dyaw2/2)^2/sl0^2])) + sl0, 
     sl0 -> l0, si0 -> (dyaw1/2 - dyaw2/2)/sl0, 
     c0 -> Sqrt[-(dyaw1/2 - dyaw2/2)^2 + sl0^2]/sl0, 
     A0 -> 3.141592653589793*r0^2, kw0 -> (A0*Y0)/sl0, 
     M01 -> 0.7853981633974483*r0^4, M02 -> 0.7853981633974483*r0^4, 
     vertblades -> True, pitchbl -> 0, pitchbr -> 0, 
     rollbl -> If[vertblades, 0, -ArcSin[si0]], 
     rollbr -> If[vertblades, 0, ArcSin[si0]], kbz -> 300, 
     bd -> (g*m0*If[vertblades, 1, 1/c0])/(2*kbz), btx -> 0.03, bty -> 0.03, 
     btz -> 0.03, temperature -> 290., boltzmann -> 1.380658*^-23, 
     alphasilica -> 5.1*^-7, betasilica -> 0.0002, rhosilica -> 2200., 
     Csilica -> 772., Ksilica -> 1.38, Ysilica -> 7.*^10, 
     phisilica -> 2.*^-8, phissilica -> 3.2999999999999996*^-11, 
     rhosteel -> 7800., Csteel -> 486., Ksteel -> 49., Ysteel -> 1.65*^11, 
     alphasteel -> 0.000012, betasteel -> -0.00025, phisteel -> 0.0002, 
     rhomarag -> 7800., Cmarag -> 460., Kmarag -> 20., Ymarag -> 1.65*^11, 
     alphamarag -> 0.000011, betamarag -> 0., phimarag -> 0.0001, 
     tmU -> 0.0045, tmI -> 0.0055, tmL -> 0.005, 
     deltablade -> (alphamarag^2*temperature*Ymarag)/(Cmarag*rhomarag), 
     taublade -> (0.10132118364233778*Cmarag*rhomarag*tmU^2)/Kmarag, 
     damping[imag, bladetype] -> 
      (phimarag + (deltablade*(2*N[Pi]*#1*taublade))/
         (1 + (2*N[Pi]*#1*taublade)^2) & ), magicnumber -> 0.0732, 
     deltafibre -> (temperature*(alphasilica - (0.3183098861837907*betasilica*
            g*m0)/(nw0*r0^2*Ysilica))^2*Ysilica)/(Csilica*rhosilica), 
     tausilica -> 4.*Csilica*magicnumber*r0^2*rhosilica, 
     damping[imag, fibretype] -> (phisilica + phissilica/(r0*2) & ), 
     damping[imag, fibreatype] -> (phisilica + phissilica/r0 + 
        (deltafibre*(2*N[Pi]*#1*tausilica))/(1 + (2*N[Pi]*#1*tausilica)^
           2) & ), x00 -> 0, y00 -> 0, z00 -> 0, yaw00 -> 0, pitch00 -> 0, 
     roll00 -> 0, kconx0 -> 0, kcony0 -> 0, kconz0 -> 0, kconyaw0 -> 0, 
     kconpitch0 -> 0, kconroll0 -> 0}
 
defaultvalues /: defaultvalues::usage = "defaultvalues is part of the \
specification of the model. It should be a list of substitutions for all \
constants. Some of the values can be given symbolically in terms of other \
constants in the list, but there should be enough given numerically that the \
whole collection becomes numeric when Recurse[] is applied."
 
g /: g::usage = "g is local gravity."
 
tx /: tx::usage = "ux is thickness of optic."
 
tr /: tr::usage = "uy is radius of optic."
 
den0 /: den0::usage = "den0 is density of optic."
 
m0 /: m0::usage = "m0 is mass of optic."
 
I0x /: I0x::usage = "I0x is x-axis MOI of optic."
 
I0y /: I0y::usage = "I0y is y-axis MOI of optic."
 
I0z /: I0z::usage = "I0z is z-axis MOI of optic."
 
l0 /: l0::usage = "l0 is part of the specification of the model and \
represents the stretched wire (fibre) length from structure to optic."
 
nw0 /: nw0::usage = "nw0 is number of wires (fibres) from structure to optic."
 
r0 /: r0::usage = "r0 is radius of wires (fibres) from structure to optic."
 
Y0 /: Y0::usage = 
     "Y0 is Young's modulus of wires (fibres) from structure to optic."
 
Ysteel /: Ysteel::usage = "Ysteel is the Young's modulus for C70 steel."
 
dpitch /: dpitch::usage = "dpitch is the height of the wire attachment points \
above the center (not COM) of the optic."
 
dyaw1 /: dyaw1::usage = "dyaw1 is the y-direction separation of the wire \
attachment points at the structure."
 
dyaw2 /: dyaw2::usage = "dyaw2 is the y-direction separation of the wire \
attachment points at the optic."
 
tl0 /: tl0::usage = "tl0 is the vertical distance from structure attachment \
point to the COM of the optic."
 
ltotal /: ltotal::usage = "ltotal is the vertical distance from the structure \
attachement point to the COM of the optic."
 
ul0 /: ul0::usage = 
     "ul0 is unstretched wire (fibre) length from structure to optic."
 
kw0 /: kw0::usage = "kw0 is net longitudinal elasticity of wires (fibres) \
from structure to optic."
 
si0 /: si0::usage = "si0 is sine of angle of fibres."
 
c0 /: c0::usage = "c0 is cosine of angle of fibres."
 
A0 /: A0::usage = "A0 is effective average cross-sectional area of wires \
(fibres) from structure to optic for the purposes of calculating the \
longitudinal elasticity."
 
M01 /: M01::usage = "M31 is the moment of area of wires (fibres) from \
structure to optic in direction \"1\""
 
M02 /: M02::usage = "M32 is the moment of area of wires (fibres) from \
structure to optic in direction \"2\""
 
temperature /: temperature::usage = "temperature is, well, guess."
 
alphasilica /: alphasilica::usage = 
     "alphasilica is the coefficient of thermal expansion for silica."
 
betasilica /: betasilica::usage = 
     "betasilica is the temperature dependence of Young's modulus for \
silica."
 
rhosilica /: rhosilica::usage = "rhosilica is the density for silica."
 
Csilica /: Csilica::usage = "Csilica is the heat capacity for silica."
 
Ksilica /: Ksilica::usage = "Ksilica is the bulk modulus for silica."
 
Ysilica /: Ysilica::usage = "Ysilica is the Young's modulus for silica."
 
phisilica /: phisilica::usage = "phisilica is the bulk loss angle for silica."
 
phissilica /: phissilica::usage = 
     "phissilica is the surface loss angle (units of m) for silica."
 
rhosteel /: rhosteel::usage = "rhosteel is the density for C70 steel."
 
Csteel /: Csteel::usage = "Csteel is the heat capacity for C70 steel."
 
Ksteel /: Ksteel::usage = "Ksteel is the bulk modulus for C70 steel."
 
alphasteel /: alphasteel::usage = 
     "alphasteel is the coefficient of thermal expansion for C70 steel."
 
betasteel /: betasteel::usage = 
     "betasteel is the temperature dependence of Young's modulus for C70 \
steel."
 
phisteel /: phisteel::usage = "phisteel is the bulk loss angle for C70 steel."
 
rhomarag /: rhomarag::usage = "rhomarag is the density for maraging steel."
 
Cmarag /: Cmarag::usage = "Cmarag is the heat capacity for maraging steel."
 
Kmarag /: Kmarag::usage = "Kmarag is the bulk modulus for maraging steel."
 
Ymarag /: Ymarag::usage = "Ymarag is the Young's modulus for maraging steel."
 
alphamarag /: alphamarag::usage = 
     "alphamarag is the coefficient of thermal expansion for maraging steel."
 
betamarag /: betamarag::usage = "betamarag is the temperature dependence of \
Young's modulus for maraging steel."
 
phimarag /: phimarag::usage = 
     "phimarag is the bulk loss angle for maraging steel."
 
damping /: damping::usage = "damping[imag,dampingtype] is a Mathematica pure \
function giving the frequency dependence of the imaginary (i.e., lossy) part \
of any potential terms tagged with symbol dampingtype. It defaults to 0& but \
can be given a value via a substitution in defaultvalues. \
damping[real,dampingtype] is the corresponding real (i.e., elastic) \
multiplier. It defaults to 1&."
 
magicnumber /: magicnumber::usage = 
     "magicnumber is a geometrical factor for thermoelastic damping."
 
deltafibre /: deltafibre::usage = "deltafibre is the thermoelastic damping \
parameter delta for the wires from mass I to the optic."
 
tausilica /: tausilica::usage = "tausilica is the thermoelastic damping \
parameter tau for the wires from mass I to the optic."
